@@ -127,7 +127,7 @@ var transform = function transform(ast, fn, moduleList) {
               && injectGlobalsReplace.hasOwnProperty(path.node.name)
               && (parent.type !== 'MemberExpression' || parent.object === path.node)
               && (parent.type !== 'Property' || parent.value === path.node)) {
-                if (!path.scope.getBindings().hasOwnProperty(path.node.name)) {
+                if (!Object.prototype.hasOwnProperty.call(path.scope.getBindings(), path.node.name)) {
                     injectGlobals.push(path.node.name);
                 }
             }
