@@ -1087,7 +1087,7 @@ namespace Private {
       // If both elements are identical, there is nothing to do.
       // This can occur when the user renders cached content.
       if (oldVNode === newVNode) {
-        currNode = currNode.nextSibling;
+        currNode = <ChildNode> currNode.nextSibling;
         continue;
       }
 
@@ -1111,7 +1111,7 @@ namespace Private {
       // If the element is a text node, update its text content.
       if (newVNode.type === 'text') {
         currNode.textContent = newVNode.tag;
-        currNode = currNode.nextSibling;
+        currNode = <ChildNode> currNode.nextSibling;
         continue;
       }
 
@@ -1126,7 +1126,7 @@ namespace Private {
       // The element tags match, update the element in place.
       updateAttrs(currNode as HTMLElement, oldVNode.attrs, newVNode.attrs);
       updateContent(currNode as HTMLElement, oldVNode.children, newVNode.children);
-      currNode = currNode.nextSibling;
+      currNode = <ChildNode> currNode.nextSibling;
     }
 
     // Dispose of the old nodes pushed to the end of the host.
@@ -1258,7 +1258,7 @@ namespace Private {
         let key = vNode.attrs.key;
         if (key) keyed[key] = { vNode, element: node as HTMLElement };
       }
-      node = node.nextSibling;
+      node = <ChildNode> node.nextSibling;
     }
     return keyed;
   }
